LSP types and re-exports
This module provides type definitions used throughout the LSP integration,
re-exporting common types from lsp-types for convenience.
Structs
- Call
Hierarchy Incoming Call - Represents an incoming call, e.g. a caller of a method or constructor.
- Call
Hierarchy Item - Call
Hierarchy Outgoing Call - Represents an outgoing call, e.g. calling a getter from a method or a method from a constructor etc.
- Diagnostic
- Represents a diagnostic, such as a compiler error or warning. Diagnostic objects are only valid in the scope of a resource.
- Diagnostic
Severity - The protocol currently supports the following diagnostic severities:
- Document
Symbol - Represents programming constructs like variables, classes, interfaces etc. that appear in a document. Document symbols can be hierarchical and they have two ranges: one that encloses its definition and one that points to its most interesting range, e.g. the range of an identifier.
- Hover
- The result of a hover request.
- Location
- Represents a location inside a resource, such as a line inside a text file.
- LspStatus
- Status of an LSP server connection
- Markup
Content - A
MarkupContentliteral represents a string value which content can be represented in different formats. Currentlyplaintextandmarkdownare supported formats. AMarkupContentis usually used in documentation properties of result literals likeCompletionItemorSignatureInformation. If the format ismarkdownthe content should follow the GitHub Flavored Markdown Specification. - Position
- Position in a text document expressed as zero-based line and character offset. A position is between two characters like an ‘insert’ cursor in a editor.
- Range
- A range in a text document expressed as (zero-based) start and end positions. A range is comparable to a selection in an editor. Therefore the end position is exclusive.
- Symbol
Information - Represents information about programming constructs like variables, classes, interfaces etc.
- Symbol
Kind - A symbol kind.
- Text
Document Identifier - Text documents are identified using a URI. On the protocol level, URIs are passed as strings.
- Text
Document Position Params - A parameter literal used in requests to pass a text document and a position inside that document.
- Uri
- Newtype struct around
fluent_uri::Uri<String>with serialization implementations that useas_str()and ‘from_str()’ respectively. - Url
- A parsed URL record.
Enums
- Document
Symbol Response - Goto
Definition Response - GotoDefinition response can be single location, or multiple Locations or a link.
- Hover
Contents - Hover contents could be single entry or multiple entries.
- LspConnection
Status - Connection status for an LSP server
- LspOperation
- LSP operation types
- LspResult
- Result from an LSP operation
- Marked
String - MarkedString can be used to render human readable text. It is either a markdown string or a code-block that provides a language and a code snippet. The language identifier is semantically equal to the optional language identifier in fenced code blocks in GitHub issues.
- Markup
Kind - Describes the content type that a client supports in various
result literals like
Hover,ParameterInfoorCompletionItem. - Workspace
Symbol Response
Constants
- IMPORTANT_
SYMBOL_ KINDS - Symbol kinds that are typically most useful for navigation
Functions
- format_
diagnostic - Format a diagnostic for display