Module types

Module types 

LSP types and re-exports

This module provides type definitions used throughout the LSP integration, re-exporting common types from lsp-types for convenience.

Structs

CallHierarchyIncomingCall
Represents an incoming call, e.g. a caller of a method or constructor.
CallHierarchyItem
CallHierarchyOutgoingCall
Represents an outgoing call, e.g. calling a getter from a method or a method from a constructor etc.
Diagnostic
Represents a diagnostic, such as a compiler error or warning. Diagnostic objects are only valid in the scope of a resource.
DiagnosticSeverity
The protocol currently supports the following diagnostic severities:
DocumentSymbol
Represents programming constructs like variables, classes, interfaces etc. that appear in a document. Document symbols can be hierarchical and they have two ranges: one that encloses its definition and one that points to its most interesting range, e.g. the range of an identifier.
Hover
The result of a hover request.
Location
Represents a location inside a resource, such as a line inside a text file.
LspStatus
Status of an LSP server connection
MarkupContent
A MarkupContent literal represents a string value which content can be represented in different formats. Currently plaintext and markdown are supported formats. A MarkupContent is usually used in documentation properties of result literals like CompletionItem or SignatureInformation. If the format is markdown the content should follow the GitHub Flavored Markdown Specification.
Position
Position in a text document expressed as zero-based line and character offset. A position is between two characters like an ‘insert’ cursor in a editor.
Range
A range in a text document expressed as (zero-based) start and end positions. A range is comparable to a selection in an editor. Therefore the end position is exclusive.
SymbolInformation
Represents information about programming constructs like variables, classes, interfaces etc.
SymbolKind
A symbol kind.
TextDocumentIdentifier
Text documents are identified using a URI. On the protocol level, URIs are passed as strings.
TextDocumentPositionParams
A parameter literal used in requests to pass a text document and a position inside that document.
Uri
Newtype struct around fluent_uri::Uri<String> with serialization implementations that use as_str() and ‘from_str()’ respectively.
Url
A parsed URL record.

Enums

DocumentSymbolResponse
GotoDefinitionResponse
GotoDefinition response can be single location, or multiple Locations or a link.
HoverContents
Hover contents could be single entry or multiple entries.
LspConnectionStatus
Connection status for an LSP server
LspOperation
LSP operation types
LspResult
Result from an LSP operation
MarkedString
MarkedString can be used to render human readable text. It is either a markdown string or a code-block that provides a language and a code snippet. The language identifier is semantically equal to the optional language identifier in fenced code blocks in GitHub issues.
MarkupKind
Describes the content type that a client supports in various result literals like Hover, ParameterInfo or CompletionItem.
WorkspaceSymbolResponse

Constants

IMPORTANT_SYMBOL_KINDS
Symbol kinds that are typically most useful for navigation

Functions

format_diagnostic
Format a diagnostic for display